@@ -23,17 +23,9 @@
 
 // these two are not accessible from python directly (though they should be in the future, perhaps)
 
-#if BOOST_VERSION>=104200
-	BOOST_CLASS_EXPORT_IMPLEMENT(BodyContainer);
-	BOOST_CLASS_EXPORT_IMPLEMENT(InteractionContainer);
-#else
-	BOOST_CLASS_EXPORT(BodyContainer);
-	BOOST_CLASS_EXPORT(InteractionContainer);
-#endif
+BOOST_CLASS_EXPORT_IMPLEMENT(BodyContainer);
+BOOST_CLASS_EXPORT_IMPLEMENT(InteractionContainer);
 
 YADE_PLUGIN((Body)(Bound)(Cell)(Dispatcher)(EnergyTracker)(Engine)(FileGenerator)(Functor)(GlobalEngine)(Interaction)(IGeom)(IPhys)(Material)(PartialEngine)(Shape)(State)(TimeStepper));
 
-EnergyTracker::~EnergyTracker(){} // vtable
-
-//BOOST_CLASS_EXPORT(OpenMPArrayAccumulator<Real>);
-//BOOST_CLASS_EXPORT(OpenMPAccumulator<Real>);
+EnergyTracker::~EnergyTracker(){}
