@@ -8,7 +8,6 @@
 	using Real = double;
 #endif
 
-#include <algorithm>
 #include <cassert>
 #include <cmath>
 #include <cstdlib>
@@ -22,7 +21,6 @@
 #include <sstream>
 #include <stdexcept>
 #include <string>
-#include <typeinfo>
 #include <utility>
 #include <vector>
 
@@ -55,8 +53,6 @@ using std::make_pair;
 #include <boost/lexical_cast.hpp>
 #include <boost/python.hpp>
 #include <boost/python/object.hpp>
-#include <boost/version.hpp>
-#include <boost/any.hpp>
 #include <boost/type_traits.hpp>
 #include <boost/preprocessor.hpp>
 #include <boost/python/module.hpp>
@@ -64,10 +60,6 @@ using std::make_pair;
 #include <boost/shared_ptr.hpp>
 #include <boost/foreach.hpp>
 #include <boost/tuple/tuple.hpp>
-#include <boost/filesystem/convenience.hpp>
-#include <boost/filesystem.hpp>
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/exception.hpp>
 #include <boost/numeric/conversion/bounds.hpp>
 
 using boost::shared_ptr;
@@ -96,9 +88,6 @@ using boost::shared_ptr;
 
 #include <Eigen/Core>
 #include <Eigen/Geometry>
-#include <Eigen/QR>
-#include <Eigen/LU>
-#include <Eigen/SVD>
 #include <Eigen/Eigenvalues>
 #include <float.h>
 
@@ -392,4 +381,4 @@ void serialize(Archive & ar, mask_t& v, const unsigned int version){
 #endif
 
 } // namespace serialization
-} // namespace boost
\ No newline at end of file
+} // namespace boost
