@@ -34,7 +34,7 @@ def saveVars(mark='',loadNow=True,**kw):
 		(1, 2, 3)
 
 	those variables will be save in the .xml file, when the simulation itself is saved. To recover those variables once the .xml is loaded again, use
-	``loadVars('something')``and they will be defined in the yade.params.\ *mark* module. The *loadNow* parameter calls :yref:`yade.utils.loadVars`
+	``loadVars('something')`` and they will be defined in the yade.params.\ *mark* module. The *loadNow* parameter calls :yref:`yade.utils.loadVars`
 	after saving automatically. If 'something' already exists, given variables will be inserted.
 	"""
 	import cPickle
@@ -110,7 +110,7 @@ def defaultMaterial():
 	"""
 	return FrictMat(density=1e3,young=1e7,poisson=.3,frictionAngle=.5,label='defaultMat')
 
-def _commonBodySetup(b,volume,geomInertia,material,pos,noBound=False,resetState=True,dynamic=None,fixed=False):
+def _commonBodySetup(b,volume,geomInertia,material,pos,noBound=False,resetState=True,dynamic=None,fixed=False,blockedDOFs='xyzXYZ'):
 	"""Assign common body parameters."""
 	if isinstance(material,int):
 		if material<0 and len(O.materials)==0: O.materials.append(defaultMaterial());
@@ -129,7 +129,7 @@ def _commonBodySetup(b,volume,geomInertia,material,pos,noBound=False,resetState=
 		import warnings
 		warnings.warn('dynamic=%s is deprecated, use fixed=%s instead'%(str(dynamic),str(not dynamic)),category=DeprecationWarning,stacklevel=2)
 		fixed=not dynamic
-	b.state.blockedDOFs=('xyzXYZ' if fixed else '')
+	b.state.blockedDOFs=(blockedDOFs if fixed else '')
 
 
 def sphere(center,radius,dynamic=None,fixed=False,wire=False,color=None,highlight=False,material=-1,mask=1):
@@ -226,85 +226,6 @@ def box(center,extents,orientation=Quaternion(1,0,0,0),dynamic=None,fixed=False,
 	return b
 
 
-def chainedCylinder(begin=Vector3(0,0,0),end=Vector3(1.,0.,0.),radius=0.2,dynamic=None,fixed=False,wire=False,color=None,highlight=False,material=-1,mask=1):
-	"""Create and connect a chainedCylinder with given parameters. The shape generated by repeted calls of this function is the Minkowski sum of polyline and sphere.
-
-	:param Real radius: radius of sphere in the Minkowski sum.
-	:param Vector3 begin: first point positioning the line in the Minkowski sum
-	:param Vector3 last: last point positioning the line in the Minkowski sum
-
-	In order to build a correct chain, last point of element of rank N must correspond to first point of element of rank N+1 in the same chain (with some tolerance, since bounding boxes will be used to create connections.
-
-	:return: Body object with the :yref:`ChainedCylinder` :yref:`shape<Body.shape>`.
-	"""
-	segment=end-begin
-	b=Body()
-	b.shape=ChainedCylinder(radius=radius,length=segment.norm(),color=color if color else randomColor(),wire=wire,highlight=highlight)
-	b.shape.segment=segment
-	V=2*(4./3)*math.pi*radius**3
-	geomInert=(2./5.)*V*radius**2+b.shape.length*b.shape.length*2*(4./3)*math.pi*radius**3
-	b.state=ChainedState()
-	b.state.addToChain(O.bodies.append(b))
-	_commonBodySetup(b,V,Vector3(geomInert,geomInert,geomInert),material,pos=begin,resetState=False,dynamic=dynamic,fixed=fixed)
-	b.mask=mask
-	b.bound=Aabb(color=[0,1,0])
-	b.state.ori.setFromTwoVectors(Vector3(0.,0.,1.),segment)
-	if (end == begin): b.state.ori = Quaternion((1,0,0),0)
-	return b
-
-def gridNode(center,radius,dynamic=None,fixed=False,wire=False,color=None,highlight=False,material=-1):
-	b=Body()
-	b.shape=GridNode(radius=radius,color=color if color else randomColor(),wire=wire,highlight=highlight)
-	#V=(4./3)*math.pi*radius**3	# will be overriden by the connection
-	V=0.
-	geomInert=(2./5.)*V*radius**2	# will be overriden by the connection
-	_commonBodySetup(b,V,Vector3(geomInert,geomInert,geomInert),material,pos=center,dynamic=dynamic,fixed=fixed)
-	b.aspherical=False
-	b.bounded=False
-	b.mask=0	#avoid contact detection with the nodes. Manual interaction will be set for them in "gridConnection" below.
-	return b
-
-def gridConnection(id1,id2,radius,wire=False,color=None,highlight=False,material=-1,mask=1,cellDist=None):
-	b=Body()
-	b.shape=GridConnection(radius=radius,color=color if color else randomColor(),wire=wire,highlight=highlight)
-	sph1=O.bodies[id1] ; sph2=O.bodies[id2]
-	i=createInteraction(id1,id2)
-	nodeMat=sph1.material
-	b.shape.node1=sph1 ; b.shape.node2=sph2
-	sph1.shape.addConnection(b) ; sph2.shape.addConnection(b)
-	if(O.periodic):
-		if(cellDist!=None):
-			i.cellDist=cellDist
-		segt=sph2.state.pos + O.cell.hSize*i.cellDist - sph1.state.pos
-	else: segt=sph2.state.pos - sph1.state.pos
-	L=segt.norm()
-	V=0.5*L*math.pi*radius**2
-	geomInert=(2./5.)*V*radius**2
-	_commonBodySetup(b,V,Vector3(geomInert,geomInert,geomInert),material,pos=sph1.state.pos,dynamic=False,fixed=True)
-	sph1.state.mass = sph1.state.mass + V*nodeMat.density
-	sph2.state.mass = sph2.state.mass + V*nodeMat.density
-	for k in [0,1,2]:
-		sph1.state.inertia[k] = sph1.state.inertia[k] + geomInert*nodeMat.density
-		sph2.state.inertia[k] = sph2.state.inertia[k] + geomInert*nodeMat.density
-	b.aspherical=False
-	if O.periodic:
-		i.phys.unp= -(sph2.state.pos + O.cell.hSize*i.cellDist - sph1.state.pos).norm() + sph1.shape.radius + sph2.shape.radius
-		b.shape.periodic=True
-		b.shape.cellDist=i.cellDist
-	else:
-		i.phys.unp= -(sph2.state.pos - sph1.state.pos).norm() + sph1.shape.radius + sph2.shape.radius	
-	i.geom.connectionBody=b
-	I=math.pi*(2.*radius)**4/64.
-	E=nodeMat.young
-	i.phys.kn=E*math.pi*(radius**2)/L
-	i.phys.kr=E*I/L
-	i.phys.ks=12.*E*I/(L**3)
-	G=E/(2.*(1+nodeMat.poisson))
-	i.phys.ktw=2.*I*G/L
-	b.mask=mask
-	return b
-	
-	
 def wall(position,axis,sense=0,color=None,material=-1,mask=1):
 	"""Return ready-made wall body.
 
@@ -323,6 +244,7 @@ def wall(position,axis,sense=0,color=None,material=-1,mask=1):
 	b.mask=mask
 	return b
 
+
 def facet(vertices,dynamic=None,fixed=True,wire=True,color=None,highlight=False,noBound=False,material=-1,mask=1,chain=-1):
 	"""Create facet with given parameters.
 
@@ -342,6 +264,7 @@ def facet(vertices,dynamic=None,fixed=True,wire=True,color=None,highlight=False,
 	b.chain=chain
 	return b
 
+
 def tetraPoly(vertices,dynamic=True,fixed=False,wire=True,color=None,highlight=False,noBound=False,material=-1,mask=1,chain=-1):
 	"""Create tetrahedron (actually simple Polyhedra) with given parameters.
 
@@ -354,7 +277,7 @@ def tetraPoly(vertices,dynamic=True,fixed=False,wire=True,color=None,highlight=F
 	inertia = b.shape.GetInertia()
 	center = b.shape.GetCentroid()
 	_commonBodySetup(b,volume,inertia,material,noBound=noBound,pos=center,fixed=fixed)
-	b.aspherical=False
+	b.aspherical=True
 	b.state.ori = b.shape.GetOri()
 	b.mask=mask
 	b.chain=chain
@@ -400,7 +323,7 @@ def polyhedron(vertices,dynamic=True,fixed=False,wire=True,color=None,highlight=
 	inertia = b.shape.GetInertia()
 	center = b.shape.GetCentroid()
 	_commonBodySetup(b,volume,inertia,material,noBound=noBound,pos=center,fixed=fixed)
-	b.aspherical=False
+	b.aspherical=True
 	b.state.ori = b.shape.GetOri()
 	b.mask=mask
 	b.chain=chain
